# -*- coding: utf-8 -*-
"""
requests_twisted : Twisted adapter for the requests library
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Tiny add-on for the requests http library so it can
be used transparently with twisted by defering blocking calls to threads.

    from requests_twisted import TwistedRequestsSession
    session = TwistedRequestsSession()
    defer = session.get('http://github.com/sametmax/')
    def print_status(response):
        print(response.url, response.status_code)
    defer.addCallback(print_status)

"""

__title__ = 'requests-twisted'
__version__ = '0.1.2'
__author__ = 'Sam et Max'
__license__ = 'Zlib'

from requests import Session
from twisted.internet import threads

class TwistedRequestsSession(Session):

    def request(self, *args, **kwargs):
        """Maintains the existing api for Session.request.

        Used by all of the higher level methods, e.g. Session.get.
        """
        func = super(TwistedRequestsSession, self).request
        return threads.deferToThread(func, *args, **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for Requests."""

from requests import Response
from requests_twisted import TwistedRequestsSession
from twisted.trial.unittest import TestCase
from twisted.internet.defer import Deferred, inlineCallbacks

class RequestsTestCase(TestCase):

    @inlineCallbacks
    def test_get(self):
        # basic futures get
        sess = TwistedRequestsSession()
        defer = sess.get('http://httpbin.org/get')
        self.assertIsInstance(defer, Deferred)

        resp = yield defer
        self.assertIsInstance(resp, Response)
        self.assertEqual(200, resp.status_code)

        resp = yield sess.get('http://httpbin.org/status/404')
        self.assertEqual(404, resp.status_code)

    @inlineCallbacks
    def test_redirect(self):
        """ Tests for the ability to cleanly handle redirects. """
        sess = TwistedRequestsSession()
        resp = yield sess.get('http://httpbin.org/redirect-to?url=get')
        self.assertIsInstance(resp, Response)
        self.assertEqual(200, resp.status_code)

        resp = yield sess.get('http://httpbin.org/redirect-to?url=status/404')
        self.assertEqual(404, resp.status_code)






#!/usr/bin/env python

from setuptools import setup

setup(
    name='requests-twisted',
    version='0.1.2',
    description='Twisted adapter for the requests library.',
    long_description=open('README.rst').read(),
    author='Sam et Max',
    author_email='lesametlemax@gmail.com',
    include_package_data=True,
    py_modules=['requests_twisted'],
    install_requires=['twisted', 'requests'],
    license='Zlib Licence',
    url='https://github.com/sametmax/requests-twisted',
    zip_safe=False,
    classifiers=(
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
    )
)
